Name:           ocaml-cfg
Version:        2.3.0
Release:        %mkrel 2
Summary:        Library for manipulation of context-free grammars (CFGs)
License:        LGPL with static compilation exception
Group:          Development/OCaml
URL:            https://mmottl.github.io/cfg/
Source0:        https://github.com/mmottl/cfg/archive/%{version}.tar.gz
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  tetex-latex
BuildRequires:  gzip
BuildRequires:  ocaml-dune
BuildRequires:  menhir

%description
This OCaml-library consists of a set of modules which implement functions
for manipulating context-free grammars (CFGs) in a purely functional way.

The core-module (cfg_impl.ml) contains a functor which allows the
parameterization of the main transformation functions with arbitrary grammar
entities that fill the demanded specification (see the interface in
"cfg_intf.mli" and the BNF-example).

Thus, you may use this module for any kind of symbol system and any kind of
representation which can be treated like a CFG.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n cfg-%{version}

%build
sed -i 's!jbuilder!dune!' Makefile
sed -i 's!--dev!!' Makefile
dune upgrade
make

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR/cfg
ocamlfind install cfg _build/install/default/lib/cfg/*

# fix debug info extraction
chmod u+w %{buildroot}%{_libdir}/ocaml/cfg/*.cmxs

%files
%doc README.md CHANGES.md
%dir %{_libdir}/ocaml/cfg
%{_libdir}/ocaml/cfg/META
%{_libdir}/ocaml/cfg/*dune*
%{_libdir}/ocaml/cfg/*.cmi
%{_libdir}/ocaml/cfg/*.cma
%{_libdir}/ocaml/cfg/*.cmxs

%files devel
%doc examples/
%{_libdir}/ocaml/cfg/*.a
%{_libdir}/ocaml/cfg/*.cmxa
%{_libdir}/ocaml/cfg/*.cmx
%{_libdir}/ocaml/cfg/*.cmt*
%{_libdir}/ocaml/cfg/*.mli
%{_libdir}/ocaml/cfg/*.ml
%{_libdir}/ocaml/cfg/opam


%changelog
* Mon Dec 23 2024 daviddavid <daviddavid> 2.3.0-2.mga10
+ Revision: 2129294
- fix debug info extraction by fixing file permissions

* Tue Oct 25 2022 pterjan <pterjan> 2.3.0-1.mga9
+ Revision: 1899321
- Update to 2.3.0

* Thu May 19 2022 pterjan <pterjan> 2.1.0-11.mga9
+ Revision: 1859006
- Rebuild for OCaml 4.14

* Fri Apr 01 2022 umeabot <umeabot> 2.1.0-10.mga9
+ Revision: 1840062
- Mageia 9 Mass Rebuild

* Fri Oct 15 2021 tv <tv> 2.1.0-9.mga9
+ Revision: 1751560
- Rebuild for ocaml 4.13.1

* Fri Mar 26 2021 tv <tv> 2.1.0-8.mga9
+ Revision: 1710396
- Rebuild for ocaml-4.12

* Sun Jan 10 2021 pterjan <pterjan> 2.1.0-7.mga8
+ Revision: 1670663
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 2.1.0-6.mga8
+ Revision: 1551482
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 2.1.0-5.mga8
+ Revision: 1543709
- Mageia 8 Mass Rebuild

* Wed Jan 22 2020 tv <tv> 2.1.0-4.mga8
+ Revision: 1482130
- rebuild for ocaml-4.10 + switch from jbuilder to dune

* Tue Oct 23 2018 tv <tv> 2.1.0-4.mga7
+ Revision: 1324185
- rebuild with ocaml-4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 2.1.0-3.mga7
+ Revision: 1299850
- Mageia 7 Mass Rebuild

* Fri Jul 06 2018 daviddavid <daviddavid> 2.1.0-2.mga7
+ Revision: 1242071
- rebuild against current ocaml stack

* Sun Nov 26 2017 tv <tv> 2.1.0-1.mga7
+ Revision: 1179912
- BR jbuilder
- new release
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 2.0.1-9.mga6
+ Revision: 1056280
- Rebuild for fix in ocaml

* Fri Feb 12 2016 umeabot <umeabot> 2.0.1-8.mga6
+ Revision: 956313
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.0.1-7.mga5
+ Revision: 740590
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.1-6.mga5
+ Revision: 683005
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.0.1-5.mga4
+ Revision: 508442
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.0.1-4.mga3
+ Revision: 361208
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 2.0.1-3.mga3
+ Revision: 301559
- rebuild for ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 2.0.1-2.mga3
+ Revision: 300052
- new rpm group for ocaml

* Tue Aug 21 2012 blue_prawn <blue_prawn> 2.0.1-1.mga3
+ Revision: 282995
- updated to last version 2.0.1

* Sun Jun 24 2012 blue_prawn <blue_prawn> 1.7.6-1.mga3
+ Revision: 262875
- updated to last version 1.7.6

* Thu Jan 12 2012 blue_prawn <blue_prawn> 1.7.5-1.mga2
+ Revision: 195096
- imported package ocaml-cfg

